@@ -2460,14 +2460,9 @@ void estimate_bc(void) {
 /** ********************************************************
  *
  ***********************************************************/
-void cb_exit()
+
+void close_ops()
 {
-	if(transmitting) {
-		transmit_stop = true;
-	}
-
-	exit_watch_dog = true;
-
 	progStatus.saveLastState();
 
 	FSEL::destroy();
@@ -2484,10 +2479,39 @@ void cb_exit()
 	debug::stop();
 
 	if(cQue) delete cQue;
+}
 
+void cb_exit()
+{
+	if(transmitting) {
+		transmit_stop = true;
+	}
+	exit_watch_dog = true;
+	close_ops();
 	exit(0);
 }
 
+/** ********************************************************
+ *  test for running fldigi made immediately after starting
+ *  the xmlrpc thread
+ ***********************************************************/
+
+void test_for_fldigi()
+{	string test = get_io_mode();
+	if (test == "NIL" || test.empty()) {
+		fl_alert2(_("Start fldigi before flamp!"));
+		if (tcpip) {
+			tcpip->close();
+			delete tcpip;
+			delete localaddr;
+		}
+		debug::stop();
+		if(cQue) delete cQue;
+		exit(0);
+	}
+}
+
+
 /** ********************************************************
  *
  ***********************************************************/
@@ -2649,28 +2673,23 @@ int main(int argc, char *argv[])
 	NBEMS_dir.clear();
 	{
 		string appname = argv[0];
-		string appdir;
+		string appdir = argv[0];
+		size_t p;
 		char dirbuf[FL_PATH_MAX + 1];
-		fl_filename_expand(dirbuf, FL_PATH_MAX, appname.c_str());
-		appdir.assign(dirbuf);
-
 #ifdef __WOE32__
-		size_t p = appdir.rfind("flamp.exe");
-		appdir.erase(p);
-		p = appdir.find("FL_APPS/");
-		if (p != string::npos) {
-			NBEMS_dir.assign(appdir.substr(0, p + 8));
-		} else {
+		p = appdir.find("FL_APPS\\");
+		if (p == string::npos) p = appdir.find("FL_APPS/");
+		if (p == string::npos) {
+			char dirbuf[FL_PATH_MAX + 1];
 			fl_filename_expand(dirbuf, sizeof(dirbuf) -1, "$USERPROFILE/");
 			NBEMS_dir.assign(dirbuf);
-		}
+		} else
+			NBEMS_dir.assign(appdir.substr(0, p + 8));
 		NBEMS_dir.append("NBEMS.files/");
-
 #else
-
 		fl_filename_absolute(dirbuf, sizeof(dirbuf), argv[0]);
 		appdir.assign(dirbuf);
-		size_t p = appdir.rfind("flamp");
+		p = appdir.rfind("flamp");
 		if (p != string::npos)
 			appdir.erase(p);
 		p = appdir.find("FL_APPS/");
@@ -2766,6 +2785,7 @@ int main(int argc, char *argv[])
 		perror("pthread_create: xmlrpc");
 		exit(EXIT_FAILURE);
 	}
+	test_for_fldigi();
 
 	try {
 		cQue = new TagSearch(receive_data_stream, process_que);
